@@ -55,12 +55,6 @@ It supports various compressed files(gzip, bzip2, zstd, lz4, and xz).
 		if config.Debug {
 			fmt.Fprintln(os.Stderr, "Using config file:", viper.ConfigFileUsed())
 		}
-		if config.General.ColumnDelimiter == "\\t" {
-			config.General.ColumnDelimiter = "\t"
-		}
-
-		oviewer.OverStrikeStyle = oviewer.ToTcellStyle(config.StyleOverStrike)
-		oviewer.OverLineStyle = oviewer.ToTcellStyle(config.StyleOverLine)
 
 		if ver {
 			fmt.Printf("ov version %s rev:%s\n", Version, Revision)
@@ -75,6 +69,14 @@ It supports various compressed files(gzip, bzip2, zstd, lz4, and xz).
 			return Completion(cmd, completion)
 		}
 
+		if config.General.ColumnDelimiter == "\\t" {
+			config.General.ColumnDelimiter = "\t"
+		}
+
+		// Set a global variable to convert to a style before opening the file.
+		oviewer.OverStrikeStyle = oviewer.ToTcellStyle(config.StyleOverStrike)
+		oviewer.OverLineStyle = oviewer.ToTcellStyle(config.StyleOverLine)
+
 		SetRedirect()
 
 		if execCommand {
@@ -179,7 +181,7 @@ func SetRedirect() {
 		oviewer.STDOUTPIPE = os.Stdout
 	}
 
-	if term.IsTerminal(int(os.Stdout.Fd())) {
+	if term.IsTerminal(int(os.Stderr.Fd())) {
 		tmpStderr := os.Stderr
 		os.Stderr = nil
 		defer func() {
@@ -244,12 +246,21 @@ func init() {
 		return []string{",\tcomma", "|\tvertical line", "\\\\t\ttab", "│\tbox"}, cobra.ShellCompDirectiveNoFileComp
 	})
 
+	rootCmd.PersistentFlags().StringP("section-delimiter", "", "", "section delimiter")
+	_ = viper.BindPFlag("general.SectionDelimiter", rootCmd.PersistentFlags().Lookup("section-delimiter"))
+
+	rootCmd.PersistentFlags().IntP("section-start", "", 0, "section start position")
+	_ = viper.BindPFlag("general.SectionStartPosition", rootCmd.PersistentFlags().Lookup("section-start"))
+
 	rootCmd.PersistentFlags().BoolP("follow-mode", "f", false, "follow mode")
 	_ = viper.BindPFlag("general.FollowMode", rootCmd.PersistentFlags().Lookup("follow-mode"))
 
 	rootCmd.PersistentFlags().BoolP("follow-all", "A", false, "follow all")
 	_ = viper.BindPFlag("general.FollowAll", rootCmd.PersistentFlags().Lookup("follow-all"))
 
+	rootCmd.PersistentFlags().BoolP("follow-section", "", false, "follow section")
+	_ = viper.BindPFlag("general.FollowSection", rootCmd.PersistentFlags().Lookup("follow-section"))
+
 	rootCmd.PersistentFlags().IntP("watch", "T", 0, "watch mode interval")
 	_ = viper.BindPFlag("general.WatchInterval", rootCmd.PersistentFlags().Lookup("watch"))
 
