@@ -64,13 +64,13 @@ func (root *Root) drawHeader() int {
 		}
 
 		lc := m.getContents(lY, m.TabWidth)
-		str, posCV := ContentsToStr(lc)
+		lineStr, posCV := m.getContentsStr(lY, lc)
 		root.lnumber[hy] = lineNumber{
 			line: lY,
 			wrap: wrapNum,
 		}
 
-		root.columnHighlight(lc, str, posCV)
+		root.columnHighlight(lc, lineStr, posCV)
 		root.blankLineNumber(hy)
 
 		lX, lY = root.drawLine(hy, lX, lY, lc)
@@ -99,7 +99,7 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 	// lc, lineStr, byteMap store the previous value.
 	// Because it may be a continuation from the previous line in wrap mode.
 	lastLN := -1
-	var lc lineContents
+	var lc contents
 	var lineStr string
 	var posCV map[int]int
 	for y := root.headerLen; y < root.vHight-statusLine; y++ {
@@ -122,8 +122,9 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 		currentY := lY
 		lX, lY = root.drawLine(y, lX, lY, lc)
 
-		root.AlternateRowsStyle(currentY, y)
+		root.alternateRowsStyle(currentY, y)
 		root.markStyle(currentY, y, markStyleWidth)
+		root.sectionLineHighlight(y, lc, lineStr)
 
 		if lX > 0 {
 			wrapNum++
@@ -136,7 +137,7 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 }
 
 // drawWrapLine wraps and draws the contents and returns the next drawing position.
-func (root *Root) drawLine(y int, lX int, lY int, lc lineContents) (int, int) {
+func (root *Root) drawLine(y int, lX int, lY int, lc contents) (int, int) {
 	if root.Doc.WrapMode {
 		return root.drawWrapLine(y, lX, lY, lc)
 	}
@@ -145,7 +146,7 @@ func (root *Root) drawLine(y int, lX int, lY int, lc lineContents) (int, int) {
 }
 
 // drawWrapLine wraps and draws the contents and returns the next drawing position.
-func (root *Root) drawWrapLine(y int, lX int, lY int, lc lineContents) (int, int) {
+func (root *Root) drawWrapLine(y int, lX int, lY int, lc contents) (int, int) {
 	if lX < 0 {
 		log.Printf("Illegal lX:%d", lX)
 		return 0, 0
@@ -160,8 +161,9 @@ func (root *Root) drawWrapLine(y int, lX int, lY int, lc lineContents) (int, int
 			break
 		}
 		content := lc[lX+x]
-		if x+content.width+root.startX > root.vWidth {
+		if x+root.startX+content.width > root.vWidth {
 			// Right edge.
+			root.clearEOL(root.startX+x, y)
 			lX += x
 			break
 		}
@@ -172,7 +174,7 @@ func (root *Root) drawWrapLine(y int, lX int, lY int, lc lineContents) (int, int
 }
 
 // drawNoWrapLine draws contents without wrapping and returns the next drawing position.
-func (root *Root) drawNoWrapLine(y int, lX int, lY int, lc lineContents) (int, int) {
+func (root *Root) drawNoWrapLine(y int, lX int, lY int, lc contents) (int, int) {
 	if lX < root.minStartX {
 		lX = root.minStartX
 	}
@@ -196,13 +198,13 @@ func (root *Root) drawNoWrapLine(y int, lX int, lY int, lc lineContents) (int, i
 
 // bodyStyle applies the style from the beginning to the end of one line of the body.
 // Apply style to contents.
-func (root *Root) bodyStyle(lc lineContents, style ovStyle) {
-	RangeStyle(lc, 0, len(lc), style)
+func (root *Root) bodyStyle(lc contents, s OVStyle) {
+	RangeStyle(lc, 0, len(lc), s)
 }
 
 // searchHighlight applies the style of the search highlight.
 // Apply style to contents.
-func (root *Root) searchHighlight(lY int, lc lineContents, lineStr string, posCV map[int]int) {
+func (root *Root) searchHighlight(lY int, lc contents, lineStr string, posCV map[int]int) {
 	if root.searchWord == "" {
 		return
 	}
@@ -239,7 +241,7 @@ func (root *Root) drawLineNumber(lY int, y int) {
 }
 
 // columnHighlight applies the style of the column highlight.
-func (root *Root) columnHighlight(lc lineContents, str string, posCV map[int]int) {
+func (root *Root) columnHighlight(lc contents, str string, posCV map[int]int) {
 	if !root.Doc.ColumnMode {
 		return
 	}
@@ -249,14 +251,14 @@ func (root *Root) columnHighlight(lc lineContents, str string, posCV map[int]int
 
 // RangeStyle applies the style to the specified range.
 // Apply style to contents.
-func RangeStyle(lc lineContents, start int, end int, style ovStyle) {
+func RangeStyle(lc contents, start int, end int, s OVStyle) {
 	for x := start; x < end; x++ {
-		lc[x].style = applyStyle(lc[x].style, style)
+		lc[x].style = applyStyle(lc[x].style, s)
 	}
 }
 
-// AlternateRowsStyle applies from beginning to end of line.
-func (root *Root) AlternateRowsStyle(lY int, y int) {
+// alternateRowsStyle applies from beginning to end of line.
+func (root *Root) alternateRowsStyle(lY int, y int) {
 	if root.Doc.AlternateRows {
 		if (lY)%2 == 1 {
 			root.lineStyle(y, root.StyleAlternate)
@@ -266,10 +268,10 @@ func (root *Root) AlternateRowsStyle(lY int, y int) {
 
 // lineStyle applies the style from the left edge to the right edge of the physical line.
 // Apply styles to the screen.
-func (root *Root) lineStyle(y int, style ovStyle) {
+func (root *Root) lineStyle(y int, s OVStyle) {
 	for x := 0; x < root.vWidth; x++ {
-		r, c, s, _ := root.GetContent(x, y)
-		root.Screen.SetContent(x, y, r, c, applyStyle(s, style))
+		r, c, ts, _ := root.GetContent(x, y)
+		root.Screen.SetContent(x, y, r, c, applyStyle(ts, s))
 	}
 }
 
@@ -296,18 +298,19 @@ func (root *Root) drawStatus() {
 	root.Screen.ShowCursor(cursorPos, root.statusPos)
 }
 
-func (root *Root) leftStatus() (lineContents, int) {
+func (root *Root) leftStatus() (contents, int) {
 	if root.input.mode == Normal {
 		return root.normalLeftStatus()
 	}
 	return root.inputLeftStatus()
 }
 
-func (root *Root) normalLeftStatus() (lineContents, int) {
+func (root *Root) normalLeftStatus() (contents, int) {
 	number := ""
 	if root.DocumentLen() > 1 && root.screenMode == Docs {
 		number = fmt.Sprintf("[%d]", root.CurrentDoc)
 	}
+
 	modeStatus := ""
 	if root.Doc.FollowMode {
 		modeStatus = "(Follow Mode)"
@@ -315,10 +318,12 @@ func (root *Root) normalLeftStatus() (lineContents, int) {
 	if root.General.FollowAll {
 		modeStatus = "(Follow All)"
 	}
+	// Watch mode doubles as FollowSection mode.
 	if root.Doc.WatchMode {
 		modeStatus += "(Watch)"
+	} else if root.Doc.FollowSection {
+		modeStatus = "(Follow Section)"
 	}
-
 	caption := root.Doc.FileName
 	if root.Doc.Caption != "" {
 		caption = root.Doc.Caption
@@ -336,7 +341,7 @@ func (root *Root) normalLeftStatus() (lineContents, int) {
 	return leftContents, len(leftContents)
 }
 
-func (root *Root) inputLeftStatus() (lineContents, int) {
+func (root *Root) inputLeftStatus() (contents, int) {
 	input := root.input
 	searchMode := ""
 	if input.mode == Search || input.mode == Backsearch {
@@ -356,7 +361,7 @@ func (root *Root) inputLeftStatus() (lineContents, int) {
 	return leftContents, len(p) + input.cursorX
 }
 
-func (root *Root) rightStatus() lineContents {
+func (root *Root) rightStatus() contents {
 	next := ""
 	if !root.Doc.BufEOF() {
 		next = "..."
@@ -366,7 +371,7 @@ func (root *Root) rightStatus() lineContents {
 }
 
 // setContentString is a helper function that draws a string with setContent.
-func (root *Root) setContentString(vx int, vy int, lc lineContents) {
+func (root *Root) setContentString(vx int, vy int, lc contents) {
 	screen := root.Screen
 	for x, content := range lc {
 		screen.SetContent(vx+x, vy, content.mainc, content.combc, content.style)
@@ -383,7 +388,22 @@ func (root *Root) clearEOL(x int, y int) {
 
 // clearLine clear the specified line.
 func (root *Root) clearLine(y int) {
-	for x := 0; x < root.vWidth; x++ {
-		root.Screen.SetContent(x, y, ' ', nil, tcell.StyleDefault)
+	root.clearEOL(0, y)
+}
+
+// columnHighlight applies the style of the column highlight.
+func (root *Root) sectionLineHighlight(y int, lc contents, str string) {
+	if root.Doc.SectionDelimiter == "" {
+		return
 	}
+
+	if root.Doc.SectionDelimiterReg == nil {
+		log.Printf("Regular expression is not set: %s", root.Doc.SectionDelimiter)
+		return
+	}
+
+	if !root.Doc.SectionDelimiterReg.MatchString(str) {
+		return
+	}
+	root.lineStyle(y, root.StyleSectionLine)
 }
