@@ -22,7 +22,7 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 	go root.updateInterval(ctx)
 
 	for {
-		if root.General.FollowAll || root.Doc.FollowMode {
+		if root.General.FollowAll || root.Doc.FollowMode || root.Doc.FollowSection {
 			root.follow()
 		}
 
@@ -57,10 +57,10 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 		case *eventPaste:
 			root.getClipboard(ctx)
 		case *eventSearch:
-			searcher := root.setSearcher(root.input.value, root.CaseSensitive)
+			searcher := root.setSearcher(ev.str, root.CaseSensitive)
 			root.searchMove(ctx, true, root.Doc.topLN+root.Doc.firstLine()+1, searcher)
 		case *eventBackSearch:
-			searcher := root.setSearcher(root.input.value, root.CaseSensitive)
+			searcher := root.setSearcher(ev.str, root.CaseSensitive)
 			root.searchMove(ctx, false, root.Doc.topLN+root.Doc.firstLine()-1, searcher)
 		case *viewModeInput:
 			root.setViewMode(ev.value)
@@ -84,6 +84,10 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 			root.setWatchInterval(ev.value)
 		case *writeBAInput:
 			root.setWriteBA(ev.value)
+		case *sectionDelimiterInput:
+			root.setSectionDelimiter(ev.value)
+		case *sectionStartInput:
+			root.setSectionStart(ev.value)
 		case *tcell.EventResize:
 			root.resize()
 		case *tcell.EventMouse:
@@ -180,7 +184,11 @@ func (root *Root) follow() {
 	}
 
 	root.skipDraw = false
-	root.TailSync()
+	if root.Doc.FollowSection {
+		root.tailSection()
+	} else {
+		root.TailSync()
+	}
 	root.Doc.latestNum = num
 }
 
@@ -203,9 +211,8 @@ func (root *Root) followAll() {
 	root.mu.RUnlock()
 
 	if root.CurrentDoc != current {
-		root.CurrentDoc = current
-		log.Printf("switch document: %d", root.CurrentDoc)
-		root.SetDocument(root.CurrentDoc)
+		log.Printf("switch document: %d", current)
+		root.switchDocument(current)
 	}
 }
 
@@ -266,11 +273,13 @@ func (root *Root) MoveBottom() {
 
 // eventSearch represents search event.
 type eventSearch struct {
+	str string
 	tcell.EventTime
 }
 
 func (root *Root) eventNextSearch() {
 	ev := &eventSearch{}
+	ev.str = root.input.value
 	ev.SetEventNow()
 	err := root.Screen.PostEvent(ev)
 	if err != nil {
@@ -280,11 +289,13 @@ func (root *Root) eventNextSearch() {
 
 // eventBackSearch represents backward search event.
 type eventBackSearch struct {
+	str string
 	tcell.EventTime
 }
 
 func (root *Root) eventNextBackSearch() {
 	ev := &eventBackSearch{}
+	ev.str = root.input.value
 	ev.SetEventNow()
 	err := root.Screen.PostEvent(ev)
 	if err != nil {
@@ -299,14 +310,8 @@ func (root *Root) Search(str string) {
 	if !root.checkScreen() {
 		return
 	}
-	if str == "" {
-		root.searchWord = ""
-		root.searchReg = nil
-		return
-	}
-	root.searchWord = str
-	root.searchReg = regexpCompile(str, root.CaseSensitive)
 	ev := &eventSearch{}
+	ev.str = str
 	ev.SetEventNow()
 	err := root.Screen.PostEvent(ev)
 	if err != nil {
@@ -321,14 +326,8 @@ func (root *Root) BackSearch(str string) {
 	if !root.checkScreen() {
 		return
 	}
-	if str == "" {
-		root.searchWord = ""
-		root.searchReg = nil
-		return
-	}
-	root.searchWord = str
-	root.searchReg = regexpCompile(str, root.CaseSensitive)
 	ev := &eventBackSearch{}
+	ev.str = str
 	ev.SetEventNow()
 	err := root.Screen.PostEvent(ev)
 	if err != nil {
