@@ -95,6 +95,15 @@ func KeyBindString(k KeyBind) string {
 	k.writeKeyBind(&b, actionSkipLines, "number of skip lines")
 	k.writeKeyBind(&b, actionTabWidth, "TAB width")
 
+	fmt.Fprint(&b, gchalk.Bold("\n\tSection\n"))
+	fmt.Fprint(&b, "\n")
+	k.writeKeyBind(&b, actionSection, "section delimiter regular expression")
+	k.writeKeyBind(&b, actionSectionStart, "section start position")
+	k.writeKeyBind(&b, actionNextSection, "next section")
+	k.writeKeyBind(&b, actionPrevSection, "previous section")
+	k.writeKeyBind(&b, actionLastSection, "last section")
+	k.writeKeyBind(&b, actionFollowSection, "follow section mode toggle")
+
 	fmt.Fprint(&b, gchalk.Bold("\n\tClose and reload\n"))
 	fmt.Fprint(&b, "\n")
 	k.writeKeyBind(&b, actionCloseFile, "close file")
