@@ -18,13 +18,15 @@ type Input struct {
 	value   string
 	cursorX int
 
-	ModeCandidate      *candidate
-	SearchCandidate    *candidate
-	GoCandidate        *candidate
-	DelimiterCandidate *candidate
-	TabWidthCandidate  *candidate
-	WatchCandidate     *candidate
-	WriteBACandidate   *candidate
+	ModeCandidate         *candidate
+	SearchCandidate       *candidate
+	GoCandidate           *candidate
+	DelimiterCandidate    *candidate
+	TabWidthCandidate     *candidate
+	WatchCandidate        *candidate
+	WriteBACandidate      *candidate
+	SectionDelmCandidate  *candidate
+	SectionStartCandidate *candidate
 }
 
 // InputMode represents the state of the input.
@@ -53,6 +55,10 @@ const (
 	SkipLines
 	// WriteBA is the number of ranges to write at quit.
 	WriteBA
+	// SectionDelimiter is a section delimiter input mode.
+	SectionDelimiter
+	// SectionStart is a section start position input mode.
+	SectionStart
 )
 
 // InputEvent input key events.
@@ -268,6 +274,22 @@ func NewInput() *Input {
 			":",
 		},
 	}
+	i.SectionDelmCandidate = &candidate{
+		list: []string{
+			"^commit",
+			"^diff",
+			"^#",
+			"^$",
+			"^\\f",
+		},
+	}
+	i.SectionStartCandidate = &candidate{
+		list: []string{
+			"2",
+			"1",
+			"0",
+		},
+	}
 	i.EventInput = &normalInput{}
 	return &i
 }
@@ -354,6 +376,22 @@ func (root *Root) setGoLineMode() {
 	input.EventInput = newGotoInput(input.GoCandidate)
 }
 
+func (root *Root) setSectionDelimiterMode() {
+	input := root.input
+	input.value = ""
+	input.cursorX = 0
+	input.mode = SectionDelimiter
+	input.EventInput = newSectionDelimiterInput(input.SectionDelmCandidate)
+}
+
+func (root *Root) setSectionStartMode() {
+	input := root.input
+	input.value = ""
+	input.cursorX = 0
+	input.mode = SectionStart
+	input.EventInput = newSectionStartInput(input.SectionStartCandidate)
+}
+
 // EventInput is a generic interface for inputs.
 type EventInput interface {
 	// Prompt returns the prompt string in the input field.
@@ -794,6 +832,78 @@ func (c *candidate) down() string {
 	return c.list[c.p]
 }
 
+// delimiterInput represents the delimiter input mode.
+type sectionDelimiterInput struct {
+	value string
+	clist *candidate
+	tcell.EventTime
+}
+
+// newSectionDelimiterInput returns sectionDelimiterInput.
+func newSectionDelimiterInput(clist *candidate) *sectionDelimiterInput {
+	return &sectionDelimiterInput{clist: clist}
+}
+
+// Prompt returns the prompt string in the input field.
+func (d *sectionDelimiterInput) Prompt() string {
+	return "Section delimiter:"
+}
+
+// Confirm returns the event when the input is confirmed.
+func (d *sectionDelimiterInput) Confirm(str string) tcell.Event {
+	d.value = str
+	d.clist.list = toLast(d.clist.list, str)
+	d.clist.p = 0
+	d.SetEventNow()
+	return d
+}
+
+// Up returns strings when the up key is pressed during input.
+func (d *sectionDelimiterInput) Up(str string) string {
+	return d.clist.up()
+}
+
+// Down returns strings when the down key is pressed during input.
+func (d *sectionDelimiterInput) Down(str string) string {
+	return d.clist.down()
+}
+
+// sectionStartInput represents the section start position input mode.
+type sectionStartInput struct {
+	value string
+	clist *candidate
+	tcell.EventTime
+}
+
+// newSectionDelimiterInput returns sectionDelimiterInput.
+func newSectionStartInput(clist *candidate) *sectionStartInput {
+	return &sectionStartInput{clist: clist}
+}
+
+// Prompt returns the prompt string in the input field.
+func (d *sectionStartInput) Prompt() string {
+	return "Section start:"
+}
+
+// Confirm returns the event when the input is confirmed.
+func (d *sectionStartInput) Confirm(str string) tcell.Event {
+	d.value = str
+	d.clist.list = toLast(d.clist.list, str)
+	d.clist.p = 0
+	d.SetEventNow()
+	return d
+}
+
+// Up returns strings when the up key is pressed during input.
+func (d *sectionStartInput) Up(str string) string {
+	return d.clist.up()
+}
+
+// Down returns strings when the down key is pressed during input.
+func (d *sectionStartInput) Down(str string) string {
+	return d.clist.down()
+}
+
 func toLast(list []string, s string) []string {
 	if len(s) == 0 {
 		return list
