@@ -1,6 +1,7 @@
 package oviewer
 
 import (
+	"context"
 	"fmt"
 	"log"
 	"strings"
@@ -75,9 +76,8 @@ func (root *Root) movePgDn() {
 
 func (root *Root) limitMoveDown(x int, y int) {
 	m := root.Doc
-	endNum := root.Doc.BufEndNum()
-	if y+root.vHight >= endNum {
-		tx, tn := root.bottomLineNum(endNum)
+	if y+root.vHight >= root.Doc.BufEndNum()-root.Doc.SkipLines {
+		tx, tn := root.bottomLineNum(root.Doc.BufEndNum())
 		if y > tn || (y == tn && x > tx) {
 			if m.topLN < tn || (m.topLN == tn && m.topLX < tx) {
 				m.topLN = tn
@@ -277,6 +277,69 @@ func (root *Root) moveDown() {
 	root.limitMoveDown(m.topLX, num)
 }
 
+func (root *Root) nextSction() {
+	// Move by page, if there is no section delimiter.
+	if root.Doc.SectionDelimiter == "" {
+		root.movePgDn()
+		return
+	}
+
+	root.resetSelect()
+	defer root.releaseEventBuffer()
+	m := root.Doc
+	num := m.topLN + m.firstLine() + (1 - root.Doc.SectionStartPosition)
+	searcher := NewSearcher(root.Doc.SectionDelimiter, root.Doc.SectionDelimiterReg, true, true)
+	ctx := context.Background()
+	defer ctx.Done()
+	n, err := m.SearchLine(ctx, searcher, num)
+	if err != nil {
+		// Last section or no section.
+		root.setMessage("no next section")
+		root.movePgDn()
+		return
+	}
+	root.moveLine((n - root.Doc.firstLine()) + root.Doc.SectionStartPosition)
+}
+
+func (root *Root) prevSection() {
+	// Move by page, if there is no section delimiter.
+	if root.Doc.SectionDelimiter == "" {
+		root.movePgUp()
+		return
+	}
+	root.resetSelect()
+	defer root.releaseEventBuffer()
+	m := root.Doc
+	num := m.topLN - (1 + root.Doc.SectionStartPosition)
+	searcher := NewSearcher(root.Doc.SectionDelimiter, root.Doc.SectionDelimiterReg, true, true)
+	ctx := context.Background()
+	defer ctx.Done()
+	n, err := m.BackSearchLine(ctx, searcher, num)
+	if err != nil {
+		root.moveLine(0)
+		return
+	}
+	root.moveLine((n - root.Doc.firstLine()) + root.Doc.SectionStartPosition)
+}
+
+func (root *Root) lastSection() {
+	root.resetSelect()
+
+	m := root.Doc
+	// +1 to avoid if the bottom line is a session delimiter.
+	num := m.BufEndNum() - 2
+	searcher := NewSearcher(root.Doc.SectionDelimiter, root.Doc.SectionDelimiterReg, true, true)
+	ctx := context.Background()
+	defer ctx.Done()
+	n, err := m.BackSearchLine(ctx, searcher, num)
+	if err != nil {
+		log.Printf("last section:%v", err)
+		return
+	}
+	n = (n - root.Doc.firstLine()) + root.Doc.SectionStartPosition
+	root.moveLine(n)
+}
+
 // Move to the left.
 // Called from a EventKey.
 func (root *Root) moveLeft() {
@@ -401,7 +464,7 @@ func (root *Root) bottomLineNum(lN int) (int, int) {
 
 	hight := (root.vHight - root.headerLen) - 2
 	if !root.Doc.WrapMode {
-		return 0, lN - (hight + root.headerLen)
+		return 0, lN - (hight + root.Doc.firstLine())
 	}
 	// WrapMode
 	lX, lN := root.findNumUp(0, lN, hight)
