@@ -131,42 +131,42 @@ type general struct {
 	FollowMode bool
 	// FollowAll is a follow mode for all documents.
 	FollowAll bool
+	// FollowSection is a follow mode that uses section instead of line.
+	FollowSection bool
 	// WatchInterval is the watch interval (seconds).
 	WatchInterval int
 	// MarkStyleWidth is width to apply the style of the marked line.
 	MarkStyleWidth int
+	// SectionDelimiter is a section delimiter.
+	SectionDelimiter string
+	// SectionDelimiterReg is a section delimiter.
+	SectionDelimiterReg *regexp.Regexp
+	// SectionStartPosition is a section start position.
+	SectionStartPosition int
 }
 
 // Config represents the settings of ov.
 type Config struct {
 	// StyleAlternate is a style that applies line by line.
-	StyleAlternate ovStyle
+	StyleAlternate OVStyle
 	// StyleHeader is the style that applies to the header.
-	StyleHeader ovStyle
+	StyleHeader OVStyle
 	// StyleHeader is the style that applies to the header.
-	StyleBody ovStyle
+	StyleBody OVStyle
 	// StyleOverStrike is a style that applies to overstrikes.
-	StyleOverStrike ovStyle
+	StyleOverStrike OVStyle
 	// OverLineS is a style that applies to overstrike underlines.
-	StyleOverLine ovStyle
+	StyleOverLine OVStyle
 	// StyleLineNumber is a style that applies line number.
-	StyleLineNumber ovStyle
+	StyleLineNumber OVStyle
 	// StyleSearchHighlight is the style that applies to the search highlight.
-	StyleSearchHighlight ovStyle
+	StyleSearchHighlight OVStyle
 	// StyleColumnHighlight is the style that applies to the column highlight.
-	StyleColumnHighlight ovStyle
+	StyleColumnHighlight OVStyle
 	// StyleMarkLine is a style that marked line.
-	StyleMarkLine ovStyle
-
-	// Old setting method.
-	// Alternating background color.
-	ColorAlternate string
-	// Header color.
-	ColorHeader string
-	// OverStrike color.
-	ColorOverStrike string
-	// OverLine color.
-	ColorOverLine string
+	StyleMarkLine OVStyle
+	// StyleSectionLine is a style that section delimiter line.
+	StyleSectionLine OVStyle
 
 	// General represents the general behavior.
 	General general
@@ -197,10 +197,21 @@ type Config struct {
 
 	// KeyBinding
 	Keybind map[string][]string
+
+	// Old setting.
+
+	// Deprecated: Alternating background color.
+	ColorAlternate string
+	// Deprecated: Header color.
+	ColorHeader string
+	// Deprecated: OverStrike color.
+	ColorOverStrike string
+	// Deprecated: OverLine color.
+	ColorOverLine string
 }
 
-// ovStyle represents a style in addition to the original style.
-type ovStyle struct {
+// OVStyle represents a style in addition to the original style.
+type OVStyle struct {
 	// Background is a color name string.
 	Background string
 	// Foreground is a color name string.
@@ -316,33 +327,37 @@ func NewOviewer(docs ...*Document) (*Root, error) {
 // NewConfig return the structure of Config with default values.
 func NewConfig() Config {
 	return Config{
-		StyleHeader: ovStyle{
+		StyleHeader: OVStyle{
 			Bold: true,
 		},
-		StyleAlternate: ovStyle{
+		StyleAlternate: OVStyle{
 			Background: "gray",
 		},
-		StyleOverStrike: ovStyle{
+		StyleOverStrike: OVStyle{
 			Bold: true,
 		},
-		StyleOverLine: ovStyle{
+		StyleOverLine: OVStyle{
 			Underline: true,
 		},
-		StyleLineNumber: ovStyle{
+		StyleLineNumber: OVStyle{
 			Bold: true,
 		},
-		StyleSearchHighlight: ovStyle{
+		StyleSearchHighlight: OVStyle{
 			Reverse: true,
 		},
-		StyleColumnHighlight: ovStyle{
+		StyleColumnHighlight: OVStyle{
 			Reverse: true,
 		},
-		StyleMarkLine: ovStyle{
+		StyleMarkLine: OVStyle{
 			Background: "darkgoldenrod",
 		},
+		StyleSectionLine: OVStyle{
+			Background: "green",
+		},
 		General: general{
-			TabWidth:       8,
-			MarkStyleWidth: 1,
+			TabWidth:             8,
+			MarkStyleWidth:       1,
+			SectionStartPosition: 0,
 		},
 	}
 }
@@ -437,7 +452,7 @@ func (root *Root) SetWatcher(watcher *fsnotify.Watcher) {
 				if !ok {
 					return
 				}
-				root.mu.RLock()
+				root.mu.Lock()
 				for _, doc := range root.DocList {
 					if doc.FileName == event.Name {
 						select {
@@ -446,7 +461,7 @@ func (root *Root) SetWatcher(watcher *fsnotify.Watcher) {
 						}
 					}
 				}
-				root.mu.RUnlock()
+				root.mu.Unlock()
 			case err, ok := <-watcher.Errors:
 				if !ok {
 					return
@@ -510,15 +525,18 @@ func (root *Root) Run() error {
 	if !root.Config.DisableMouse {
 		root.Screen.EnableMouse()
 	}
+	root.Config.General.SectionDelimiterReg = regexpCompile(root.Config.General.SectionDelimiter, true)
 
 	root.optimizedMan()
 
 	for n, doc := range root.DocList {
-		log.Printf("open [%d]%s", n, doc.FileName)
 		doc.general = root.Config.General
+		w := ""
 		if doc.general.WatchInterval > 0 {
-			doc.WatchMode = true
+			doc.watchMode()
+			w = "(watch)"
 		}
+		log.Printf("open [%d]%s%s", n, doc.FileName, w)
 	}
 
 	root.setModeConfig()
@@ -613,7 +631,7 @@ func (root *Root) debugMessage(msg string) {
 	log.Printf("%s:%s", root.Doc.FileName, msg)
 }
 
-func ToTcellStyle(s ovStyle) tcell.Style {
+func ToTcellStyle(s OVStyle) tcell.Style {
 	style := tcell.StyleDefault
 	style = style.Background(tcell.GetColor(s.Background))
 	style = style.Foreground(tcell.GetColor(s.Foreground))
@@ -628,7 +646,7 @@ func ToTcellStyle(s ovStyle) tcell.Style {
 	return style
 }
 
-func applyStyle(style tcell.Style, s ovStyle) tcell.Style {
+func applyStyle(style tcell.Style, s OVStyle) tcell.Style {
 	if s.Background != "" {
 		style = style.Background(tcell.GetColor(s.Background))
 	}
@@ -659,6 +677,42 @@ func applyStyle(style tcell.Style, s ovStyle) tcell.Style {
 	return style
 }
 
+// overwriteGeneral overwrites a general structure with a struct.
+func overwriteGeneral(a general, b general) general {
+	if b.TabWidth != 0 {
+		a.TabWidth = b.TabWidth
+	}
+	if b.Header != 0 {
+		a.Header = b.Header
+	}
+	if b.SkipLines != 0 {
+		a.SkipLines = b.SkipLines
+	}
+	a.AlternateRows = b.AlternateRows
+	a.ColumnMode = b.ColumnMode
+	a.LineNumMode = b.LineNumMode
+	a.WrapMode = b.WrapMode
+	a.FollowMode = b.FollowMode
+	a.FollowAll = b.FollowAll
+	a.FollowSection = b.FollowSection
+	if b.ColumnDelimiter != "" {
+		a.ColumnDelimiter = b.ColumnDelimiter
+	}
+	if b.WatchInterval != 0 {
+		a.WatchInterval = b.WatchInterval
+	}
+	if b.MarkStyleWidth != 0 {
+		a.MarkStyleWidth = b.MarkStyleWidth
+	}
+	if b.SectionDelimiter != "" {
+		a.SectionDelimiter = b.SectionDelimiter
+	}
+	if b.SectionStartPosition != 0 {
+		a.SectionStartPosition = b.SectionStartPosition
+	}
+	return a
+}
+
 // prepareView prepares when the screen size is changed.
 func (root *Root) prepareView() {
 	screen := root.Screen
