@@ -38,6 +38,8 @@ const (
 	XZ
 )
 
+const FormFeed = "\f"
+
 func compressType(header []byte) Compressed {
 	switch {
 	case bytes.Equal(header[:3], []byte{0x1f, 0x8b, 0x8}):
@@ -110,6 +112,8 @@ func compressedFormatReader(cFormat Compressed, reader io.Reader) io.Reader {
 
 // ReadFile reads file.
 func (m *Document) ReadFile(fileName string) error {
+	m.mu.Lock()
+	defer m.mu.Unlock()
 	if fileName == "" {
 		if term.IsTerminal(0) {
 			return ErrMissingFile
@@ -193,21 +197,22 @@ func (m *Document) onceFollowMode() {
 		return
 	}
 
+	var cancel context.CancelFunc
 	ctx := context.Background()
-	ctx, m.cancel = context.WithCancel(ctx)
-	go m.startFollowMode(ctx)
+	ctx, cancel = context.WithCancel(ctx)
+	go m.startFollowMode(ctx, cancel)
+	m.cancel = cancel
 }
 
 // startFollowMode opens the file in follow mode.
 // Seek to the position where the file was closed, and then read.
-func (m *Document) startFollowMode(ctx context.Context) {
-	defer m.cancel()
+func (m *Document) startFollowMode(ctx context.Context, cancel context.CancelFunc) {
+	defer cancel()
 	<-m.followCh
 	if m.seekable {
 		// Wait for the file to open until it changes.
 		select {
 		case <-ctx.Done():
-			log.Println("follow mode cancel")
 			return
 		case <-m.changCh:
 		}
@@ -284,6 +289,7 @@ func (m *Document) ContinueReadAll(ctx context.Context, r io.Reader) error {
 }
 
 // readAll actually reads everything.
+// The read lines are stored in the lines of the Document.
 func (m *Document) readAll(reader *bufio.Reader) error {
 	var line strings.Builder
 
@@ -313,6 +319,23 @@ func (m *Document) append(lines ...string) {
 	atomic.StoreInt32(&m.changed, 1)
 }
 
+func (m *Document) appendFormFeed() {
+	line := ""
+	m.mu.Lock()
+	if m.endNum > 0 {
+		line = m.lines[m.endNum-1]
+	}
+	m.mu.Unlock()
+
+	// Do not add if the previous is FormFeed.
+	if line != FormFeed {
+		m.append(FormFeed)
+	}
+}
+
+// reload will read again.
+// Regular files are reopened and reread increase.
+// The pipe will reset what it has read.
 func (m *Document) reload() error {
 	if (m.file == os.Stdin && m.BufEOF()) || !m.seekable && m.checkClose() {
 		return fmt.Errorf("%w %s", ErrAlreadyClose, m.FileName)
@@ -329,7 +352,12 @@ func (m *Document) reload() error {
 		}
 	}
 
-	m.reset()
+	if m.WatchMode {
+		m.appendFormFeed()
+	} else {
+		m.reset()
+		m.topLN = 0
+	}
 
 	if !m.seekable {
 		return nil
@@ -339,6 +367,7 @@ func (m *Document) reload() error {
 	return m.ReadFile(m.FileName)
 }
 
+// reset clears all lines.
 func (m *Document) reset() {
 	m.mu.Lock()
 	m.endNum = 0
@@ -348,6 +377,7 @@ func (m *Document) reset() {
 	m.ClearCache()
 }
 
+// checkClose returns if the file is closed.
 func (m *Document) checkClose() bool {
 	return atomic.LoadInt32(&m.closed) == 1
 }
